==> 1.1.5.tar.gz: lib/src/executor.dart <==
import 'dart:io';
import 'dart:mirrors';
import 'package:args/args.dart';
import 'package:recase/recase.dart';
import 'package:drun/src/write_help.dart';
import 'package:drun/src/annotations.dart';
import 'package:drun/src/type_parser.dart';

const _version = '1.1.5';

Future<void> executor(
  LibraryMirror lib,
  Iterable<MethodMirror> tasks,
  ArgResults parsedArgv,
) async {
  if (parsedArgv.wasParsed('version')) {
    stdout.writeln(_version);
    return;
  }

  if (parsedArgv.command == null) {
    await writeHelp(parsedArgv, tasks);
    return;
  }

  var task = tasks.singleWhere(
      (_) => _.simpleName == Symbol(parsedArgv.command.name.camelCase));

  if (parsedArgv.wasParsed('help')) {
    await writeHelp(parsedArgv, [task]);
    return;
  }

  var taskParameterValues = task.parameters.map((p) {
    var pName = MirrorSystem.getName(p.simpleName).paramCase;
    var v = parsedArgv.command[pName];

    if (v != null) {
      return typeParser(p.type.reflectedType, v);
    }

    if (Env.hasMetadata(p)) {
      var envKey = Env.fromMetadata(p).value;
      if (Platform.environment.containsKey(envKey)) {
        return typeParser(
          p.type.reflectedType,
          Platform.environment[envKey],
        );
      }
    }

    if (p.hasDefaultValue) {
      return p.defaultValue.reflectee;
    }

    throw 'The option --${pName} is required!';
  }).toList();

  var result = lib.invoke(task.simpleName, taskParameterValues).reflectee;

  if (result is Future) {
    await result;
  }
}

==> 2.0.0.tar.gz: lib/src/executor.dart <==
import 'dart:io';
import 'dart:mirrors';
import 'package:args/args.dart';
import 'package:recase/recase.dart';
import 'package:drun/src/write_help.dart';
import 'package:drun/src/annotations.dart';
import 'package:drun/src/type_parser.dart';
import 'package:dotenv/dotenv.dart' as dotenv;

const _version = '2.0.0';

Future<void> executor(
  Map<Uri, LibraryMirror> libs,
  Map<String, MethodMirror> tasks,
  Map<String, MethodMirror> options,
  ArgResults parsedArgv,
) async {
  if (parsedArgv.wasParsed('version')) {
    stdout.writeln(_version);
    return;
  }

  if (parsedArgv.command == null) {
    await writeHelp(tasks, options, parsedArgv);
    return;
  }

  var task = tasks[parsedArgv.command.name];

  if (parsedArgv.wasParsed('help')) {
    await writeHelp({parsedArgv.command.name: task}, options, parsedArgv);
    return;
  }

  var taskParameterValues = task.parameters.map((p) {
    var pName = MirrorSystem.getName(p.simpleName).paramCase;
    var v = parsedArgv.command[pName];

    if (v != null) {
      return typeParser(p.type.reflectedType, v);
    }

    if (Env.hasMetadata(p)) {
      var envKey = Env.fromMetadata(p).value;
      if (dotenv.env.containsKey(envKey)) {
        return typeParser(
          p.type.reflectedType,
          dotenv.env[envKey],
        );
      }
    }

    if (p.hasDefaultValue) {
      return p.defaultValue.reflectee;
    }

    throw 'The option --${pName} is required!';
  }).toList();

  var result = libs[task.location.sourceUri]
      .invoke(task.simpleName, taskParameterValues)
      .reflectee;

  if (result is Future) {
    await result;
  }
}
